from .base import BaseMongoModel
import bcrypt

def validate_password(password, hashed_password):
    bcrypt.checkpw(password.encode('utf-8'), hashed_password)

def hash_password(password):
    return bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt())

class AuthenticatableModel(BaseMongoModel):

    collection_name = "users"

    @classmethod
    def login(cls, **credentials):
        docs = cls.collection.find_one(**credentials)

        if docs is None:
            return None
        
        # Validate Password:
        if not validate_password(credentials['password'], docs['password']):
            return None
        
        return docs

    @classmethod
    def register(cls, **data):
        data['password'] = hash_password(data['password'])
        return cls.create(**data)